@@ -19,7 +19,7 @@ import pytest
 from _pytest.terminal import TerminalReporter
 
 
-__version__ = '0.3.4'
+__version__ = '0.3.5'
 
 LEN_RIGHT_MARGIN = 5
 LEN_PROGRESS_BAR = 10
@@ -62,7 +62,8 @@ def pytest_deselected(items):
     if len(items) > 0:
         pluginmanager = items[0].config.pluginmanager
         terminal_reporter = pluginmanager.getplugin('terminalreporter')
-        terminal_reporter.tests_count -= len(items)
+        if terminal_reporter.tests_count > 0:
+            terminal_reporter.tests_count -= len(items)
 
 
 def pytest_addoption(parser):
@@ -192,15 +193,15 @@ class SugarTerminalReporter(TerminalReporter):
 
     def begin_new_line(self, report, print_filename):
         basename = os.path.basename(report.fspath)
+        if self.showlongtestinfo:
+            test_location = report.location[0]
+            test_name = report.location[2]
+        else:
+            test_location = report.fspath[0:-len(basename)]
+            test_name = report.fspath[-len(basename):]
         if print_filename:
-            self.current_line = (
-                "   " +
-                TERMINAL_COLORS['gray'] +
-                report.fspath[0:-len(basename)] +
-                TERMINAL_COLORS['endc'] +
-                report.fspath[-len(basename):] +
-                " "
-            )
+            self.current_line = ("   " + TERMINAL_COLORS['gray'] + test_location +
+                                 TERMINAL_COLORS['endc'] + test_name + " ")
         else:
             self.current_line = " " * (4 + len(report.fspath))
         print("")
@@ -217,6 +218,11 @@ class SugarTerminalReporter(TerminalReporter):
         len_line = real_string_length(self.current_line)
         return len_line == max_column_for_test_status
 
+    def pytest_runtest_logstart(self, nodeid, location):
+        # Prevent locationline from being printed since we already
+        # show the module_name & in verbose mode the test name.
+        pass
+
     def pytest_runtest_logreport(self, report):
         self.reports.append(report)
         if report.outcome == 'failed':
@@ -236,8 +242,9 @@ class SugarTerminalReporter(TerminalReporter):
             if self.reached_last_column_for_test_status():
                 self.begin_new_line(report, print_filename=False)
         if report.when == 'call':
-            if report.fspath != self.currentfspath2:
-                self.currentfspath2 = report.fspath
+            path = report.location if self.showlongtestinfo else report.fspath
+            if path != self.currentfspath2:
+                self.currentfspath2 = path
                 self.begin_new_line(report, print_filename=True)
 
             rep = report
@@ -259,9 +266,7 @@ class SugarTerminalReporter(TerminalReporter):
                     elif rep.skipped:
                         markup = {'yellow': True}
                 line = self._locationline(str(rep.fspath), *rep.location)
-                if not hasattr(rep, 'node'):
-                    self.write_ensure_prefix(line, word, **markup)
-                else:
+                if hasattr(rep, 'node'):
                     self.ensure_newline()
                     if hasattr(rep, 'node'):
                         self._tw.write("[%s] " % rep.node.gateway.id)
@@ -311,7 +316,7 @@ class SugarTerminalReporter(TerminalReporter):
 
         if self.count('skipped') > 0:
             self.write_line(
-                TERMINAL_COLORS['fail'] +
+                TERMINAL_COLORS['okblue'] +
                 "   %d skipped" % self.count('skipped') +
                 TERMINAL_COLORS['endc']
             )
